scxpand.autoencoders.ae\_modules
================================

.. automodule:: scxpand.autoencoders.ae_modules

   
   .. rubric:: Functions

   .. autosummary::
   
      apply_inverse_transforms_to_mean
      dropout_activation
      theta_activation
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseAutoencoder
      CategoricalHead
      ClassificationHead
      Decoder
      Encoder
   